@@ -14,14 +14,21 @@ sub arg_defines {
 
   s/"/""/g foreach values %args;
 
-  my $config_defines = '';
+  my $config_defines;
 
   # VMS can only have one define qualifier; add the one from config, if any.
   if ($self->{config}{ccflags} =~ s{/def[^=]+(?:=)+(?:\()?([^\/\)]*)} {}i) {
-    $config_defines = "$1,";
+    $config_defines = $1;
   }
 
-  return ('/define=(' . $config_defines . join(',', map "\"$_=$args{$_}\"", keys %args) . ')');
+  return unless (scalar keys %args) || $config_defines;
+
+  return ('/define=(' 
+          . (defined $config_defines ? "$config_defines," : '')
+          . join(',', 
+                 map "\"$_" . ( length($args{$_}) ? "=$args{$_}" : '') . "\"", 
+                     keys %args) 
+          . ')');
 }
 
 sub arg_include_dirs {
